OPTIONS nocenter nodate nonumber linesize=MAX pagesize=MAX formdlim='-';
TITLE; 

* Turn on SAS graphics, set style that allows plot lines to be distinguished
  on the basis of color, style, or maker;
ODS GRAPHICS ON;
ODS HTML STYLE=htmlbluecml;
ODS RTF STARTPAGE=NO BODYTITLE STYLE=htmlbluecml 
	FILE="C:\Documents and Settings\lesa\My Documents\Dropbox\!PSYC 943\Lectures\21 Power Analysis in SAS\SAS Example.rtf";

/* Options within PLOT for PROC POWER:

X = Effect or N or Power for what goes on X-axis, solving for Y-axis
Min = minimum x-axis value, Max = maximum x-axis value
Key = ByCurve (numbered legend) or ByFeature (style legend) or OnCurves (on plot)
VarY (Color or LineStyle or Panel or Symbol BY Dimension) */

/* Options within MULTREG for PROC POWER:

Model = FIXED for categorical predictors, RANDOM for MVN continuous predictors
Alpha = .05 is default, choose others as you wish

INCLUDE ONLY TWO OF THREE BELOW for N predictors:
	NFullPredictors = # of predictors total in regression
	NReducedPredictors = # of predictors in reduced alternative model
	NTestPredictors = difference in # of predictors between models

SPECIFYING EFFECT SIZE: INCLUDE ONLY TWO OF THREE BELOW RSQ OPTIONS
	RsqFull = one or more R2 values of full model
	RsqReduced = one or more R2 values of reduced model
	RsqDiff = one or more diff in R2 between full and reduced models
OR CHOOSE PartialCorr = one or more partial correlations to be detected

NTotal = Total sample size (put . if you want it to be calculated)
Power = . if you want power to be calculated */


TITLE1 "Power to Detect Range of Partial Correlations";
TITLE2 "Will calculate power for sample sizes around Ntotal";
PROC POWER;
	MULTREG	Model=random NFullPredictors=4 NTestPredictors=1
			Alpha=.05 PartialCorr= .1 .2 .3 .4 .5 NTotal=100 Power=.;
	PLOT X=N Min=50 Max=200 Key=OnCurves;	
RUN;

TITLE1 "Power to Detect Range of Partial Correlations";
TITLE2 "Will calculate Ntotal for 80% power at each partial correlation";
PROC POWER;
	MULTREG	Model=random NFullPredictors=4 NTestPredictors=1
			Alpha=.05 PartialCorr= .1 .2 .3 .4 .5 NTotal=. Power=.80;
	PLOT X=Effect Min=.1 Max=.5 Key=OnCurves;	
RUN;

TITLE1 "Power to Detect Range of Incremental R2";
TITLE2 "Will calculate power for sample sizes around Ntotal";
PROC POWER;
	MULTREG	Model=random NFullPredictors=3 NTestPredictors=3
			Alpha=.05 RsqReduced=0 RsqDiff=.05 .10 .15 .20  NTotal=100 Power=.;
	PLOT X=N Min=50 Max=200 Key=OnCurves;	
RUN;

TITLE1 "Power to Detect Range of Incremental R2";
TITLE2 "Will calculate Ntotal for 80% power at each R2";
PROC POWER;
	MULTREG	Model=random NFullPredictors=3 NTestPredictors=3
			Alpha=.05 RsqReduced=0 RsqDiff=.05 .10 .15 .20  NTotal=. Power=.80;
	PLOT X=Effect Min=.05 Max=.30 Key=OnCurves;	
RUN;

/* Options within ONEWAYANOVA for PROC POWER:

Test = Contrast for df=1 or Overall for omnibus F
GroupMeans = list mean per group separated by |
Stddev = list common SD (no way to do differently per group)
GroupWeights = (relative sample size of each group)
GroupNs = actual group sample sizes
NPerGroup = sample size per group (use if equal)
Contrast = (contrast codes to specific differences)

NTotal = Total sample size (put . if you want it to be calculated)
Power = . if you want power to be calculated */

TITLE1 "Power to Detect Range of Omnibus Between-Group Mean Differences";
TITLE2 "Will calculate power for sample sizes around Ntotal";
PROC POWER;
* 3 groups: Drug, Drug+Caffeine, Placebo, using means from previous research;
* SDs should have been 10.8, 12.4, and 7.1, but it only allows a common SD;
	ONEWAYANOVA	GroupMeans= 11.4 | 16.7 | 4.0 Stddev=10.0 GroupWeights=(1 1 1)(2 2 1)
				Test=Overall Alpha=.05 Ntotal=90 Power=.;
	PLOT X=N Min=30 Max=180 Key=OnCurves;	
RUN;

TITLE1 "Power to Detect Range of Specific Between-Group Mean Differences";
TITLE2 "Will calculate power for sample sizes around Ntotal";
PROC POWER;
* 3 groups: Drug, Drug+Caffeine, Placebo, using means from previous research;
* SDs should have been 10.8, 12.4, and 7.1, but it only allows a common SD;
	ONEWAYANOVA	GroupMeans= 11.4 | 16.7 | 4.0 Stddev=10.0 GroupWeights=(1 1 1)(2 2 1)
				Test=Contrast Alpha=.05 Ntotal=90 Power=.
				Contrast= (-1 -1 2) (-1  1 0);
	PLOT X=N Min=30 Max=180 Key=OnCurves;	
RUN;


TITLE1 "Power to Detect Range of Omnibus Between-Group Mean Differences";
TITLE2 "Will calculate power for sample sizes around Ntotal";
PROC POWER;
* 3 groups: Drug, Drug+Caffeine, Placebo, using std mean differences;
	ONEWAYANOVA	GroupMeans= .4 | .6 | 0 Stddev=1 GroupWeights=(1 1 1)(2 2 1)
				Test=Overall Alpha=.05 Ntotal=90 Power=.;
	PLOT X=N Min=30 Max=180 Key=OnCurves;	
RUN;

TITLE1 "Power to Detect Range of Specific Between-Group Mean Differences";
TITLE2 "Will calculate power for sample sizes around Ntotal";
PROC POWER;
* 3 groups: Drug, Drug+Caffeine, Placebo, using std mean differences;
	ONEWAYANOVA	GroupMeans= .4 | .6 | 0 Stddev=1 GroupWeights=(1 1 1)(2 2 1)
				Test=Contrast Alpha=.05 Ntotal=90 Power=.
				Contrast= (-1 -1 2) (-1  1 0);
	PLOT X=N Min=30 Max=180 Key=OnCurves;	
RUN;

/* Options within PAIREDMEANS for PROC POWER:

TEST = Diff provides test of mean difference
PairedMeans = Means to be tested for difference
PairedStddevs = Measure-specific SD for means to be tested
Stddev = Common SD for means to be tested
MeanDiff = Mean difference to be tested
Corr = correlations between measures

NPairs = Total # persons measured repeatedly (put . if you want it to be calculated)
Power = power level (put . if you want power to be calculated) */

TITLE1 "Power to Detect Range of Repeated Measures Mean Differences";
TITLE2 "Will calculate power for sample sizes around Npairs";
PROC POWER;
	PAIREDMEANS	MeanDiff= .2 .4 .6 Stddev=1 Corr= .3 .7
				Alpha=.05 Npairs=25 Power=.;
	PLOT X=N Min=10 Max=50 Key=OnCurves VarY(Panel BY Corr);	
RUN;

ODS HTML CLOSE; ODS RTF CLOSE; 
