OPTIONS nocenter nodate nonumber linesize=MAX pagesize=MAX formdlim='-' 
nomprint nosymbolgen nomlogic; TITLE; ODS TRACE OFF; ODS GRAPHICS OFF;

* GENERATE DATA FOR ANOVA MODEL;

* SIMULATION SPECIFICS;
%GLOBAL n1 n2 n3 mean1 mean2 mean3 sd1 sd2 sd3 ngroups nreps SeedVar;
%LET ngroups = 3;
%LET mean1 = 11.4;
%LET mean2 = 16.7;
%LET mean3 = 4.0;
%LET sd1 = 10.0;
%LET sd2 = 10.0;
%LET sd3 = 10.0;
%LET n1 = 20;
%LET n2 = 20;
%LET n3 = 20;
%LET nreps = 100;
%LET SeedVar = 7;

* Generate nresps datasets of fake people;
%MACRO simulateANOVA;
DATA ANOVAsim;
	CALL streaminit(&SeedVar.); *set random seed;
	%DO replication = 1 %TO &nreps.;
		%DO group = 1 %TO &ngroups.;
			%DO n = 1 %TO &&n&group.;
				Y = RAND('NORMAL',%SYSEVALF(&&mean&group.),%SYSEVALF(&&sd&group.));
				mean = &&mean&group.; sd = &&sd&group.; group=&group.; 
				person=&n.; replication=&replication.;
				OUTPUT;
			%END; *person loop;
		%END; *group loop;
	%END; *replication loop;
RUN;
%MEND simulateANOVA;
%simulateANOVA;

* Run ANOVA per dataset, save results;
PROC GLM DATA=ANOVAsim;
	BY replication;
	CLASS group;
	MODEL y = group / SS3;
	ODS OUTPUT FitStatistics=R2 ModelANOVA=SumSquares OverallANOVA=ANOVA LSMeans=Means; 
	LSMEANS group;
RUN;
* Code Omnibus F-test as significant or not;
DATA SumSquares; SET SumSquares; 
	IF ProbF LT .05 THEN Signif=1; ELSE Signif=0;
RUN;
TITLE "Proportion Significant Omnibus F-test for Group";
PROC MEANS DATA=SumSquares; VAR Signif; RUN;
TITLE "Simulated Group Means";
PROC MEANS DATA=Means; CLASS Group; VAR yLSmean; RUN;
TITLE;

* SDs should have been 10.8, 12.4, and 7.1, but it only allows a common SD;
%GLOBAL n1 n2 n3 mean1 mean2 mean3 sd1 sd2 sd3 ngroups nreps SeedVar;
%LET ngroups = 3;
%LET mean1 = 11.4;
%LET mean2 = 16.7;
%LET mean3 = 4.0;
%LET sd1 = 10.8;
%LET sd2 = 12.4;
%LET sd3 = 7.1;
%LET n1 = 20;
%LET n2 = 20;
%LET n3 = 20;
%LET nreps = 100;
%LET SeedVar = 77;
%simulateANOVA;

* FOR UNEQUAL VARIANCES;
PROC MIXED DATA=ANOVAsim METHOD=ML;
	BY replication;
	CLASS group person;
	MODEL y = group / SOLUTION DDFM=KR;
	LSMEANS group / PDIFF=ALL;
	REPEATED / SUBJECT=person*group GROUP=group;
	ODS OUTPUT Diffs=LSMEANDIFF Tests3 = Tests3;
RUN;

DATA Tests3; SET Tests3;
	IF ProbF LT .05 THEN Signif=1; ELSE Signif=0;
RUN;
DATA LSMEANDIFF; SET LSMEANDIFF;
	IF ProbT LT .05 THEN Signif=1; ELSE Signif=0;
RUN;
PROC SORT DATA=LSMEANDIFF; BY Group _Group; RUN;

TITLE "Proportion Significant Omnibus F-test for Group";
PROC MEANS DATA=Tests3 MEAN; VAR Signif; RUN;
TITLE "Simulated Group Mean Differences";
PROC MEANS DATA=LSMEANDIFF MEAN; BY Group _Group; VAR Signif; RUN;
TITLE;

* To clear results viewer in between runs;
ODS HTML CLOSE; ODS HTML;



