##############################################################################################################
#data for class example
perf = c(10,12,14,16,12)
iq = c(112,113,115,118,114)

maxiq = max(iq)+10
miniq = min(iq)-10

meaniq = mean(iq)
iqMC = iq-meaniq


plot(iqMC,perf,col="black",cex=1.5,pch=16,xlab="IQ-114.4",ylab="Performance",xlim=c(-3,5),ylim=c(10,17),
     main="Class Example Data")

##############################################################################################################
#section for plotting a line and some points with residual lines - in class example


beta0 = 13
beta1= 1
miniq = -4
maxiq = 6

#LS Coefficients:
out = lm(perf~iqMC)
beta0 = out$coef[1]
beta1 = out$coef[2]


y_low = beta0+beta1*miniq
y_high = beta0+beta1*maxiq

plot(iqMC,perf,col="black",cex=1.5,pch=16,xlab="IQ-114.4",ylab="Performance",xlim=c(-3,5),ylim=c(10,17),
     main="Least Squares Estimates")

text(-1,16,labels = substitute(beta[0] == A,list(A = beta0)),cex=2)
text(-1,15.5,labels = substitute(beta[1] == A,list(A = beta1)),cex=2)

lines(c(miniq,maxiq),c(y_low,y_high),lwd=4)

sse = 0
n = dim(matrix(perf))[1]
for (i in 1:n) {
  yhat=beta0+beta1*iqMC[i]
  sse = sse+(perf[i]-yhat)^2
}

for (i in 1:5)
  {
    lines(c(iqMC[i],iqMC[i]),c(perf[i],beta0+beta1*iqMC[i]),lwd=1,lty=3)
  }

text(-1,15,labels = substitute(SSE == A,list(A = sse)),cex=2)


##############################################################################################################
#section for plotting the LS Surface

x=matrix(0,1,1)
y=matrix(0,1,1)
z=matrix(0,1,1)

  
intSTART = 12.6
intEND = 13.0
intSTEP = .02
slopeSTART = .76
slopeEND = 1.16
slopeSTEP = .02
DV = perf
IV = iqMC

#intSTEP=slopeSTEP
n = dim(matrix(DV))[1]
slope = seq(slopeSTART,slopeEND,slopeSTEP)
int = seq(intSTART,intEND,intSTEP)

nstep = dim(matrix(slope))[1]

x=matrix(0,nstep,1)
y=matrix(0,nstep,1)
z=matrix(0,nstep,nstep)

count=1
for (i in 1:nstep){
  for (j in 1:nstep){
    beta0 = int[i]
    beta1 = slope[j]
    
    x[i] = beta0
    y[j] = beta1
    
    #compute predicted values
    yhat = matrix(0,n,1)
    sse = 0
    for (k in 1:n) {
      yhat[k]=beta0+beta1*IV[k]
      sse = sse+(DV[k]-yhat[k])^2
    }
    
    z[i,j] = sse
    
  }
  
}

#creating surface plot for MVN
library(fields)
library(mnormt)

grid.list=list(x=x,y=y)
z1=z[1:mudim-1,1:mudim-1]
mygrid=make.surface.grid(grid.list)
out=list(x=grid.list$x,y=grid.list$y,z=z)
par(mfrow=c(1,2))
plot.surface(out,type="p",xlab="Intercept",ylab="Slope",zlab="SSE",main="Optimization Function for LS")
plot.surface(out,type="c",xlab="test",ylab="Slope",zlab="SSE",main="Optimization Function for LS")


##############################################################################################################
#section for plotting the L1 Surface

x=matrix(0,1,1)
y=matrix(0,1,1)
z=matrix(0,1,1)


intSTART = 12.36
intEND = 12.76
intSTEP = .02
slopeSTART = .95
slopeEND = 1.05
slopeSTEP = .005
DV = perf
IV = iqMC

#intSTEP=slopeSTEP
n = dim(matrix(DV))[1]
slope = seq(slopeSTART,slopeEND,slopeSTEP)
int = seq(intSTART,intEND,intSTEP)

nstep = dim(matrix(slope))[1]

x=matrix(0,nstep,1)
y=matrix(0,nstep,1)
z=matrix(0,nstep,nstep)

minsse = 10000
minbeta0=0
minbeta1=0
count=1
for (i in 1:nstep){
  for (j in 1:nstep){
    beta0 = int[i]
    beta1 = slope[j]
    
    x[i] = beta0
    y[j] = beta1
    
    #compute predicted values
    yhat = matrix(0,n,1)
    sse = 0
    for (k in 1:n) {
      yhat[k]=beta0+beta1*IV[k]
      sse = sse+abs(DV[k]-yhat[k])
    }
    
    z[i,j] = sse
    if (sse<minsse) {
      minsse = sse
      minbeta0=beta0
      minbeta1=beta1
    }
  }
  
}

#creating surface plot for MVN
library(fields)
library(mnormt)

grid.list=list(x=x,y=y)

mygrid=make.surface.grid(grid.list)
out=list(x=grid.list$x,y=grid.list$y,z=z)
par(mfrow=c(1,2))
plot.surface(out,type="p",xlab="Intercept",ylab="Slope",zlab="SAD",main="Optimization Function for LAD")
plot.surface(out,type="c",xlab="test",ylab="Slope",zlab="SAD",main="Optimization Function for LAD")

##############################################################################################################
#PLOT COMPARING LS AND L1 ESTIMATES

maxiq = max(iq)+10
miniq = min(iq)-10

meaniq = mean(iq)
iqMC = iq-meaniq


miniq = -4
maxiq = 6

#LS Coefficients:
out = lm(perf~iqMC)
beta0 = out$coef[1]
beta1 = out$coef[2]

plot(iqMC,perf,col="black",cex=1.5,pch=16,xlab="IQ-114.4",ylab="Performance",xlim=c(-3,5),ylim=c(10,17),
     main="Comparison of Regression Slope Estimates")

beta0 = out$coef[1]
beta1 = out$coef[2]

y_low = beta0+beta1*miniq
y_high = beta0+beta1*maxiq

lines(c(miniq,maxiq),c(y_low,y_high),lwd=4)

beta0 = 12.4
beta1= 1

y_low = beta0+beta1*miniq
y_high = beta0+beta1*maxiq

lines(c(miniq,maxiq),c(y_low,y_high),lwd=4,lty=2)

legend(-2,16,c("LS","LAbs Dev"),lty=1:2,lwd=4,cex=2)



##############################################################################################################
#PLOT COMPARING LS AND L1 ESTIMATES for 6-observation example

perf = c(10,12,14,16,12,2)
iq = c(112,113,115,118,114,120)

iqMC = iq-114.4


miniq = -4
maxiq = 8

#LS Coefficients:
out = lm(perf~iqMC)
beta0 = out$coef[1]
beta1 = out$coef[2]
par(mfrow=c(1,1))
plot(iqMC,perf,col="black",cex=1.5,pch=16,xlab="IQ-114.4",ylab="Performance",xlim=c(-3,7),ylim=c(1,17),
     main="Comparison of Regression Slope Estimates")

beta0 = out$coef[1]
beta1 = out$coef[2]

y_low = beta0+beta1*miniq
y_high = beta0+beta1*maxiq

lines(c(miniq,maxiq),c(y_low,y_high),lwd=4,lty=3)

beta0 = 12.8
beta1 = .96

y_low = beta0+beta1*miniq
y_high = beta0+beta1*maxiq

lines(c(miniq,maxiq),c(y_low,y_high),lwd=4)

beta0 = 12.4
beta1= 1

y_low = beta0+beta1*miniq
y_high = beta0+beta1*maxiq

lines(c(miniq,maxiq),c(y_low,y_high),lwd=4,lty=2)

legend(-2,5,c("Old LS","LAbs Dev", "New LS"),lty=1:3,lwd=4,cex=2)