OPTIONS nonumber nodate nocenter pagesize=MAX linesize=120 formdlim='-';											
* Kill default titles on output; 
TITLE;
*TURN OFF HTML OUTPUT;
ODS HTML CLOSE;
*TURN ON LISTING OUTPUT;
ODS LISTING;


* CHANGE THIS TO YOUR FOLDER:;
%LET filepath = C:\Work\06. Teaching\0. My Courses\2012\PSYC 943 - Multivariate\Lectures\10 Introduction to Matrix Algebra and PROC IML\SAS Examples\SAS Examples;

*NAME A PERMANANT LIBRARY FOR SAS DATA;
LIBNAME SAT "&filepath."; 

*IMPORT SAT DATA (COMMA DELIMITED) INTO SAS LIBRARY;
DATA SAT.satdata;
    INFILE "&filepath.\sat.csv"
		DLM = ',' DSD FIRSTOBS=2;
    INPUT satv satm;
RUN;

*COPY SAT DATA TO TEMPORARY (WORK) DIRECTORY;
DATA work.satdata;
	SET SAT.satdata;
RUN;

PROC IML;
RESET PRINT; *THIS LINE PRINTS THE RESULTS FROM ALL MATRIX EQUATIONS;

*READ IN DATA FROM DATA SET AND PUT INTO MATRIX X;
USE work.satdata;
READ ALL VAR _ALL_ INTO X;

*COLUMN VECTORS FROM X;
SATV = X[,1];
SATM = X[,2];

*DIAGONAL MATRIX A;
A = {2.759 0 0,
     0 1.643 0,
	 0 0 0.879};

*DEFINING VECTORS FROM SLIDES;
a = {1,
     2};

b = {2,
	 3};

*LENGTH OF VECTORS;
len_a = SQRT(a[##,]); 
len_b = SQRT(b[##,]);

len_SATV = SQRT(SATV[##,]);
len_SATM = SQRT(SATM[##,]);

*VECTOR ADDITION;
c = a + b;
z = a + SATV;
SATTOTAL = SATV+SATM;

*VECTOR MULTIPLICATION BY SCALAR;
d = 2*a;
len_d = SQRT(d[##,]);

*NORMALIZING VECTORS;
a_norm = a/len_a;
len_a_norm = SQRT(a_norm[##,]);

*DOT PRODUCT;
a_dot_b = t(a)*b;
v_dot_m = t(SATV)*SATM;

*VECTOR ANGLE;
cosangleSAT = v_dot_m/(len_SATV*len_SATM);
angleSAT = arcos(cosangleSAT);

*COSINE OF ANGLE OF MEAN-CENTERED VECTORS = CORRELATION;
N = NROW(X);
SATV_MU = SATV[+,]/N*J(N,1,1);
SATM_MU = SATM[+,]/N*J(N,1,1);

SATVc = SATV-SATV_MU;
SATMc = SATM-SATM_MU;

len_SATVc = SQRT(SATVc[##,]);
len_SATMc = SQRT(SATMc[##,]);

vc_dot_mc = t(SATVc)*SATMc;
cosangleSATc = vc_dot_mc/(len_SATVc*len_SATMc);

*PROJECTION OF SATV ONTO SATM;
SATV_PROJ_SATM1 = (v_dot_m /(len_SATM)**2);
SATV_PROJ_SATM2 = SATV_PROJ_SATM1*SATM;

*MATRIX MULTIPLICATION SAT EXAMPLE;
XTX = t(X)*X;
XTXinv = inv(XTX);

*EIGENVALUE AND EIGENVECTOR EXAMPLE;
R = {1 .78, .78 1};

CALL EIGEN(Val,Vec,R);

R1 = Val[1,1]*Vec[,1]*t(Vec[,1]);
R2 = R1 + Val[2,1]*Vec[,2]*t(Vec[,2]);

QUIT;

*FOR CHECKING CORRELATION;
PROC CORR DATA=satdata;
VAR SATV SATM;
RUN;

*FOR CHECKING PROJECTION;
PROC GLM DATA=satdata;
MODEL SATM = SATV / SOLUTION;
OUTPUT OUT=residout residual=residual predicted=predicted;
RUN; QUIT;
