*ORIGINAL DATA FROM http://www.ats.ucla.edu/stat/sas/library/repeated_ut.htm;
OPTIONS NONUMBER NODATE NOCENTER PAGESIZE=MAX LINESIZE=120 formdlim='-';
* Kill default titles on output;
TITLE;

*TURN OUTPUT FORMAT INTO JOURNAL STYLE;
ODS HTML STYLE=JOURNAL;

*TURN ON ODS STATEMENTS TO DETERMINE TABLE NAMES FOR OUTPUT;
ODS TRACE ON;

*VALUE LABELS FOR EACH LEVEL OF OUR CATEGORICAL VARIABLES;
PROC FORMAT;
VALUE exercises
    1 = "Aerobic Stair Climbing"
    2 = "Racquetball"
    3 = "Weight Training";

VALUE diets
    1 = "Meat Eaters"
    2 = "Vegetarians";

VALUE intensities
	1 = "Pulse: Warm Up"
	2 = "Pulse: Jogging"
	3 = "Pulse: Running";
RUN;


DATA work.dietwide;
INPUT exertype pulse1 pulse2 pulse3 diet personID;

LABEL exertype = "Exercise Type"
      pulse1 = "Pulse After Warmup"
      pulse2 = "Pulse After Jogging"
      pulse3 = "Pulse After Running"
      diet = "Diet Type";



    IF exertype = 1 THEN DO; dEXERCISE_ASC = 1; dEXERCISE_R = 0; dEXERCISE_WT = 0; END;
    IF exertype = 2 THEN DO; dEXERCISE_ASC = 0; dEXERCISE_R = 1; dEXERCISE_WT = 0; END;
    IF exertype = 3 THEN DO; dEXERCISE_ASC = 0; dEXERCISE_R = 0; dEXERCISE_WT = 1; END;



    IF diet = 1 THEN DO; dDIET_M = 1; dDIET_V = 0; END;
    IF diet = 2 THEN DO; dDIET_M = 0; dDIET_V = 1; END;

DATALINES;
1         112       166       215       1      1
1         111       166       225       1      2
1         89        132       189       1      3
1         95        134       186       2      4
1         66        109       150       2      5
1         69        119       177       2      6
2         125       177       241       1      7
2         85        117       186       1      8
2         97        137       185       1      9
2         93        151       217       2     10
2         77        122       178       2     11
2         78        119       173       2     12
3         81        134       205       1     13
3         88        133       180       1     14
3         88        157       224       1     15
3         58         99       131       2     16
3         85        132       186       2     17
3         78        110       164       2     18
;

RUN;


*CALCULATING MEAN VECTOR AND COVARIANCE MATRIX FOR ALL THREE VARIABLES USING PROC IML;
PROC IML;
    *READ IN DATA FROM DATA SET AND PUT INTO MATRIX X;
    USE work.dietwide;
    READ ALL VAR _ALL_ INTO X;

    *USE ONLY THE COLUMNS WIH THE PULSE MEASUREMENTS;
    X = X[,2:4];

    *NUMBER OF OBSERVATIONS IN X:;
    N = NROW(X);

    *ONES VECTOR WITH SAME LENGTH AS NUMBER OF OBSERVATIONS;
    ONES = J(N,1,1); *J function (built in) creates a new matrix with (#rows, #cols, value of element);

    *CALCULATION OF THE MEAN VECTOR;
    meanvec = (1/N)*t(X)*ONES; *t() function (built in) transposes the matrix in the parentheses;

    *CALCULATION OF THE COVARIANCE MATRIX;
    mean_matrix = ONES*t(meanvec); *for covariance matrix;
    cov_matrix = (1/N)*t(X - mean_matrix)*(X - mean_matrix);

    PRINT meanvec;

    PRINT cov_matrix;

QUIT;

*GLM WITH ML FOR ONE DV (CAN USE WIDE DATA AS ONLY ONE DV IS PRESENT):;
PROC MIXED DATA=WORK.DIETWIDE METHOD=ML COVTEST NOPROFILE ITDETAILS IC NAMELEN=50;
CLASS exertype;
FORMAT exertype exercises. diet diets.;
MODEL PULSE3 = /S;
REPEATED exertype / R RCORR;
RUN;

*CONVERTING DATA TO STACKED FORM FOR PROC MIXED;
DATA WORK.dietstack;
    SET WORK.dietwide;

	*FIRST OUTCOME: PULSE 1 (AFTER WARM UP);
	pulse = pulse1;
    intensity = 1; 
	dINTENSITY_W = 1; dINTENSITY_J = 0; dINTENSITY_R = 0; *DUMMY CODED VARIABLES FOR ANALYSIS;
    OUTPUT; *OUTPUT MAKES THE LINE OF DATA GET WRITTEN TO THE NEW DATA SET;

	*SECOND OUTCOME: PULSE 2 (AFTER JOGGING);
    pulse = pulse2;
    intensity = 2; 
	dINTENSITY_W = 0; dINTENSITY_J = 1; dINTENSITY_R = 0; 
    OUTPUT;
	
	*THIRD OUTCOME: PULSE 3 (AFTER RUNNING);
    pulse = pulse3;
    intensity = 3; 
	dINTENSITY_W = 0; dINTENSITY_J = 0; dINTENSITY_R = 1;
    OUTPUT;

RUN;
TITLE "EMPTY MULTIVARIATE MODEL, VC ERROR: (PREDICTORS ARE INDICATORS OF WHICH VARIABLE)";
PROC MIXED DATA=WORK.dietstack METHOD=ML COVTEST NOPROFILE ITDETAILS IC NAMELEN=50;
CLASS intensity;
MODEL pulse = dINTENSITY_W dINTENSITY_R / S DDFM=KENWARDROGER;
REPEATED intensity / SUBJECT=personID TYPE=VC R RCORR;
RUN;
TITLE;

TITLE "EMPTY MULTIVARIATE MODEL, FULL UNSTRUCTURED ERROR VARIANCE MODEL: (PREDICTORS ARE INDICATORS OF WHICH VARIABLE) - MULTIVARIATE ANOVA ASSUMPTION";
PROC MIXED DATA=WORK.dietstack METHOD=ML COVTEST NOPROFILE ITDETAILS IC NAMELEN=50;
CLASS intensity;
MODEL pulse = dINTENSITY_W dINTENSITY_R / S DDFM=KENWARDROGER;
REPEATED intensity / SUBJECT=personID TYPE=UN R RCORR;
RUN;
TITLE;

TITLE "EMPTY MULTIVARIATE MODEL, FULL UNSTRUCTURED ERROR VARIANCE MODEL: (PREDICTORS ARE INDICATORS OF WHICH VARIABLE) - MULTIVARIATE ANOVA ASSUMPTION";
PROC MIXED DATA=WORK.dietstack METHOD=ML COVTEST NOPROFILE ITDETAILS IC NAMELEN=50;
CLASS intensity;
MODEL pulse = dINTENSITY_W dINTENSITY_R / S DDFM=KENWARDROGER;
REPEATED intensity / SUBJECT=personID TYPE=UN R RCORR;
ESTIMATE 'Mean Pulse for Warm Up' intercept 1 dINTENSITY_W 1;
ESTIMATE 'Mean Pulse for Jogging' intercept 1;
ESTIMATE 'Mean Pulse for Running' intercept 1 dINTENSITY_R 1;
ESTIMATE 'Warm Up/Jogging Difference' dINTENSITY_W 1;
ESTIMATE 'Warm Up/Running Difference' dINTENSITY_W 1 dINTENSITY_R -1;
ESTIMATE 'Jogging/Running Difference' dINTENSITY_R -1;
CONTRAST 'Test for Overall Within Subject Difference' dINTENSITY_W 1, dINTENSITY_R 1;
RUN;
TITLE;

*==================================MODEL COMPARISONS;

TITLE "EMPTY MULTIVARIATE MODEL, VC ERROR: (PREDICTORS ARE INDICATORS OF WHICH VARIABLE)";
PROC MIXED DATA=WORK.dietstack METHOD=ML COVTEST NOPROFILE ITDETAILS IC NAMELEN=50;
CLASS intensity;
MODEL pulse = dINTENSITY_W dINTENSITY_R / S DDFM=KENWARDROGER;
REPEATED intensity / SUBJECT=personID TYPE=VC R RCORR;
ODS OUTPUT INFOCRIT=info_model1 R=r_model1;
RUN;
TITLE;


*FOR MODEL COMPARISON;
DATA work.info_model1;
	SET work.info_model1;
	modelname = 'Variance Components                                 ';
	modelnumber = 1;
RUN;


TITLE "EMPTY MULTIVARIATE MODEL, HETEROGENEOUS ERROR VARIANCE/INDEPENDENT OBS MODEL: (PREDICTORS ARE INDICATORS OF WHICH VARIABLE)";
PROC MIXED DATA=WORK.dietstack METHOD=ML COVTEST NOPROFILE ITDETAILS IC NAMELEN=50;
CLASS intensity;
MODEL pulse = dINTENSITY_W dINTENSITY_R / S DDFM=KENWARDROGER;
REPEATED intensity / SUBJECT=personID TYPE=UN(1) R RCORR;
ODS OUTPUT INFOCRIT=info_model2 R=r_model2;
RUN;
TITLE;

*FOR MODEL COMPARISON;
DATA work.info_model2;
	SET work.info_model2;
	modelname = 'Heterogeneous Variance/Independence';
	modelnumber = 2;
RUN;


TITLE "EMPTY MULTIVARIATE MODEL, COMPOUND SYMMETRIC ERROR VARIANCE MODEL: (PREDICTORS ARE INDICATORS OF WHICH VARIABLE) - REPEATED MEASURES ASSUMPTION";
PROC MIXED DATA=WORK.dietstack METHOD=ML COVTEST NOPROFILE ITDETAILS IC NAMELEN=50;
CLASS intensity;
MODEL pulse = dINTENSITY_W dINTENSITY_R / S DDFM=KENWARDROGER;
REPEATED intensity / SUBJECT=personID TYPE=CS R RCORR;
ODS OUTPUT INFOCRIT=info_model3 R=r_model3;
RUN;
TITLE;

*FOR MODEL COMPARISON;
DATA work.info_model3;
	SET work.info_model3;
	modelname = 'Compound Symmetry';
	modelnumber = 3;
RUN;

TITLE "EMPTY MULTIVARIATE MODEL, HETEROGENEOUS COMPOUND SYMMETRIC ERROR VARIANCE MODEL: (PREDICTORS ARE INDICATORS OF WHICH VARIABLE)";
PROC MIXED DATA=WORK.dietstack METHOD=ML COVTEST NOPROFILE ITDETAILS IC NAMELEN=50;
CLASS intensity;
MODEL pulse = dINTENSITY_W dINTENSITY_R / S DDFM=KENWARDROGER;
REPEATED intensity / SUBJECT=personID TYPE=CSH R RCORR;
ODS OUTPUT INFOCRIT=info_model4 R=r_model4;
RUN;
TITLE;

*FOR MODEL COMPARISON;
DATA work.info_model4;
	SET work.info_model4;
	modelname = 'Compound Symmetry - Heterogeneous Variances';
	modelnumber = 4;
RUN;


TITLE "EMPTY MULTIVARIATE MODEL, FULL UNSTRUCTURED ERROR VARIANCE MODEL: (PREDICTORS ARE INDICATORS OF WHICH VARIABLE) - MULTIVARIATE ANOVA ASSUMPTION";
PROC MIXED DATA=WORK.dietstack METHOD=ML COVTEST NOPROFILE ITDETAILS IC NAMELEN=50;
CLASS intensity;
MODEL pulse = dINTENSITY_W dINTENSITY_R / S DDFM=KENWARDROGER;
REPEATED intensity / SUBJECT=personID TYPE=UN R RCORR;
ODS OUTPUT INFOCRIT=info_model5 R=r_model5;
RUN;
TITLE;

*FOR MODEL COMPARISON;
DATA work.info_model5;
	SET work.info_model5;
	modelname = 'Unstructured Covariances (All Estimated)';
	modelnumber = 5;
RUN;

DATA work.info_compare;
	SET work.info_model1-work.info_model5;
RUN;

PROC PRINT DATA=work.info_compare;
RUN;
