OPTIONS NOCENTER NODATE NONUMBER LINESIZE=80 formdlim='-';
TITLE; /* An initial TITLE command gets rid of SAS System top info */
%LET filepath = C:\Dropbox\!PSYC 943\Lectures\18 Missing Data with ML and MI\SAS Example;
%INC "&filepath.\multnorm.sas";

*THE DATA;
DATA work.jobperf;
INPUT ID IQ perfC perfMCAR perfMAR;
DATALINES;
1 78 9 . .
2 84 13 13 .
3 84 10 . .
4 85 8 8 .
5 87 7 7 .
6 91 7 7 7
7 92 9 9 9
8 94 9 9 9
9 94 11 11 11
10 96 7 . 7
11 99 7 7 7
12 105 10 10 10
13 105 11 11 11
14 106 15 15 15
15 108 10 10 10
16 112 10 . 10
17 113 12 12 12
18 115 14 14 14
19 118 16 16 16
20 134 12 . 12
;
RUN;


*GETTING ML COVARIANCE MATRIX: For each type of data;
*COMPLETE DATA;
DATA WORK.complete;
	SET WORK.jobperf;
	KEEP IQ perfC;
RUN;

*MCAR DATA;
DATA WORK.mcar;
	SET WORK.jobperf;
	KEEP IQ perfMCAR;
	IF perfMCAR~=.;
RUN;

*MAR DATA;
DATA WORK.mar;
	SET WORK.jobperf;
	KEEP IQ perfMAR;
	IF perfMAR~=.;
RUN;

PROC IML;
	USE WORK.complete;
	READ ALL VAR _ALL_ INTO X;

	N = NROW(X);
	xbar = (1/N)*(t(X)*J(N,1,1));
	PRINT xbar;

	Sx = (1/N)*t(X-J(N,1,1)*t(xbar))*(X-J(N,1,1)*t(xbar));
	PRINT Sx;	

	USE WORK.mcar;
	READ ALL VAR _ALL_ INTO X;

	N = NROW(X);
	xbar = (1/N)*(t(X)*J(N,1,1));
	PRINT xbar;

	Sx = (1/N)*t(X-J(N,1,1)*t(xbar))*(X-J(N,1,1)*t(xbar));
	PRINT Sx;

	USE WORK.mar;
	READ ALL VAR _ALL_ INTO X;

	N = NROW(X);
	xbar = (1/N)*(t(X)*J(N,1,1));
	PRINT xbar;

	Sx = (1/N)*t(X-J(N,1,1)*t(xbar))*(X-J(N,1,1)*t(xbar));
	PRINT Sx;
QUIT;


*GETTING DESCRIPTIVE STATISTICS WITH AND WITHOUT MISSING DATA;
PROC MEANS DATA=WORK.jobperf MEAN STD VAR N;
VAR IQ perfC perfMCAR perfMAR;
RUN;

PROC CORR DATA=WORK.jobperf COV;
VAR IQ perfC perfMCAR perfMAR;
RUN;

*CONVERTING DATA TO STACKED FOR PROC MIXED;
DATA WORK.jobstack;
	SET WORK.jobperf;

	value = IQ;
	variable = "IQ                  ";
	OUTPUT;

	value = perfC;
	variable = "Performance Complete" ;
	OUTPUT;

	KEEP ID value variable;
RUN;

*EMPTY MODEL: Complete Data;
PROC MIXED DATA=WORK.jobstack METHOD=ML COVTEST NOPROFILE ITDETAILS IC;
CLASS variable;
MODEL value = variable / S;
REPEATED / SUBJECT=ID TYPE=UN R RCORR;
RUN;

*EMPTY MODEL: Complete Data -- demonstration of likelihood ratio test - no repeated statement;
*Null Model:;
PROC MIXED DATA=WORK.jobstack METHOD=ML COVTEST NOPROFILE ITDETAILS IC;
CLASS variable;
MODEL value = variable / S;
RUN;

*MISSING DATA WITH MAXIMUM LIKELIHOOD: PROC MIXED;
*CONVERTING DATA TO STACKED FOR PROC MIXED;
DATA WORK.jobstackMCAR;
	SET WORK.jobperf;

	value = IQ;
	variable = "IQ                  ";
	OUTPUT;

	value = perfMCAR;
	variable = "Performance MCAR";
	OUTPUT;

	KEEP ID value variable;
RUN;

*EMPTY MODEL: MCAR Data;
PROC MIXED DATA=WORK.jobstackMCAR METHOD=ML COVTEST NOPROFILE ITDETAILS IC;
CLASS variable;
MODEL value = variable / S;
REPEATED / SUBJECT=ID TYPE=UN R=1,2 RCORR;
RUN;

*MISSING DATA WITH MAXIMUM LIKELIHOOD: PROC MIXED;
*CONVERTING DATA TO STACKED FOR PROC MIXED;
DATA WORK.jobstackMAR;
	SET WORK.jobperf;

	value = IQ;
	variable = "IQ                  ";
	OUTPUT;

	value = perfMAR;
	variable = "Performance MAR";
	OUTPUT;

	KEEP ID value variable;
RUN;

*EMPTY MODEL: MAR Data;
PROC MIXED DATA=WORK.jobstackMAR METHOD=ML COVTEST NOPROFILE ITDETAILS IC ASYCOV EMPIRICAL;
CLASS variable;
MODEL value = variable / S;
REPEATED / SUBJECT=ID TYPE=UN R=1,10 RCORR;
RUN;
