
*************************************************************************************;
*DATA EXAMPLE #2;
DATA WORK.fitmiss;
INPUT Oxygen RunTime RunPulse MissingPattern;
DATALINES;
44.609  11.37  178 0
54.297   8.65  156 0
49.874   9.22    . 1
.       11.95  176 4
39.442  13.08  174 0
50.541    .      . 3
44.754  11.12  176 0
51.855  10.33  166 0
40.836  10.95  168 0
46.774  10.25    . 1
39.407  12.63  174 0
45.441   9.63  164 0
45.118  11.08    . 1
45.790  10.47  186 0
48.673   9.40  186 0
47.467  10.50  170 0
45.313  10.07  185 0
59.571    .      . 3
44.811  11.63  176 0
   .    10.85    . 5
60.055   8.63  170 0
37.388  14.03  186 0
47.273    .      . 3
49.156   8.95  180 0
46.672  10.00    . 1
50.388  10.08  168 0
46.080  11.17  156 0
  .      8.92    . 5
39.203  12.88  168 0
50.545   9.93  148 0
47.920  11.50  170 0
;
RUN;

*CONVERT TO TEMPORARY WORK DATA SET;
DATA WORK.fitmiss;
	SET WORK.fitmiss;
	IF oxygen=. THEN OxygenMiss=1; ELSE OxygenMiss=0;
	IF runtime=. THEN RunTimeMiss=1; ELSE RunTimeMiss=0;
	IF runpulse=. THEN RunPulseMiss=1; ELSE RunPulseMiss=0;
	ID = _N_;
RUN;


*ADDING VALUE LABELS TO MISSING PATTERN VARIBLE;
PROC FORMAT;
VALUE MissingPatternValue 0 = "None Missing"
						  1 = "Pulse Missing"
						  3 = "Time and Pulse Missing"
						  4 = "Oxygen Missing"
						  5 = "Oxygen and Pulse Missing";
VALUE MissingIndicator 0 = "Not Missing"
					   1 = "Missing";
RUN;
*GET DESCRIPIVE STATISTICS FOR DATA WITHOUT MISSING VALUES;
PROC MEANS DATA=WORK.fitmiss MEAN STD N; 
VAR oxygen runtime runpulse;
RUN;

*INSPECTING MISSING VALUE PATTERNS:;
PROC FREQ DATA=WORK.fitmiss;
FORMAT MissingPattern MissingPatternValue.;
TABLE MissingPattern;
RUN;

*SORTING DATA SO AS TO CALCULATE MISSING VALUES;
PROC SORT DATA=WORK.fitmiss;
BY MissingPattern;
RUN;

*GET DESCRIPIVE STATISTICS FOR DATA;
PROC MEANS DATA=WORK.fitmiss MEAN STD N; 
FORMAT MissingPattern MissingPatternValue.;
BY MissingPattern;
VAR oxygen runtime runpulse;
RUN;

*SORTING DATA SO AS TO CALCULATE MISSING VALUES;
PROC SORT DATA=WORK.fitmiss;
BY oxygenmiss;
RUN;

*GET DESCRIPIVE STATISTICS FOR DATA;
PROC MEANS DATA=WORK.fitmiss MEAN STD N; 
FORMAT oxygenmiss MissingIndicator.;
BY oxygenmiss;
VAR oxygen runtime runpulse;
RUN;

*SORTING DATA SO AS TO CALCULATE MISSING VALUES;
PROC SORT DATA=WORK.fitmiss;
BY runtimemiss;
RUN;

*GET DESCRIPIVE STATISTICS FOR DATA;
PROC MEANS DATA=WORK.fitmiss MEAN STD N; 
FORMAT runtimemiss MissingIndicator.;
BY runtimemiss;
VAR oxygen runtime runpulse;
RUN;

*SORTING DATA SO AS TO CALCULATE MISSING VALUES;
PROC SORT DATA=WORK.fitmiss;
BY runpulsemiss;
RUN;

*GET DESCRIPIVE STATISTICS FOR DATA;
PROC MEANS DATA=WORK.fitmiss MEAN STD N; 
FORMAT runpulsemiss MissingIndicator.;
BY runpulsemiss;
VAR oxygen runtime runpulse;
RUN;


*LISTWISE DELETION EXAMPLE;
*REGRESSION ANALYSIS WITH MISSING DATA;
*INITIAL MODEL: PREDICTING OXYGEN WITH RUNTIME ONLY;
PROC GLM DATA=WORK.fitmiss;
MODEL oxygen = runtime / SOLUTION SS3;
RUN;

*SEQUENTIAL MODEL: ADDING RUNPULSE;
PROC GLM DATA=WORK.fitmiss;
MODEL oxygen = runtime runpulse / SOLUTION SS3;
RUN;

*PAIRWISE DELETION EXAMPLE - SAVES COVARIANCE MATRIX FOR PROC IML ANALYSIS;
PROC CORR DATA=WORK.fitmiss COV OUTP=WORK.covmiss;
VAR oxygen runtime runpulse;
RUN;

*SINGLE IMPUTATION EXAMPLE;
*UNCONDITIONAL MEAN EXAMPLE;
DATA WORK.fit_UCmean;
	SET WORK.fitmiss;
	IF oxygen=. THEN oxygen=47.1;
	IF runtime=. THEN runtime=10.7;
	IF runpulse=. THEN runpulse=171.9;
RUN;

*OUTPUT MEANS AFTER IMPUTING;
PROC MEANS DATA=WORK.fit_UCmean MEAN STD N;
VAR oxygen runtime runpulse;
RUN;

*DEMONSTRATING CONDITIONAL MEAN EXAMPLE:;
PROC IML;

USE WORK.covmiss;
READ ALL VAR _ALL_ INTO BIG;

SIGMAfull = BIG[1:3,1:3];
MUfull = {47.1, 10.7, 171.9};

PRINT MUfull;
PRINT SIGMAfull;

*CONDITIONAL DISTRIBUTION OF OXYGEN GIVEN RUNTIME AND PULSE;
MU1 = MUfull[1,1];
MU2 = MUfull[2:3,1];
PRINT MU1 MU2;

SIGMA11 = SIGMAfull[1,1];
SIGMA12 = SIGMAfull[1,2:3];
SIGMA22 = SIGMAfull[2:3,2:3];
SIGMA21 = SIGMAfull[2:3,1];
PRINT SIGMA11;
PRINT SIGMA12;
PRINT SIGMA21;
PRINT SIGMA22;

invSIGMA22 = inv(SIGMA22);
PRINT invSIGMA22;

*FOR OBSERVATION #22, MISSING OXYGEN ONLY:;

X22 = {11.96 176};
OXYGEN_mean = MU1+SIGMA12*INV(SIGMA22)*(t(X22)-MU2);
PRINT OXYGEN_mean;

OXYGEN_var = SIGMA11 - SIGMA12*inv(SIGMA22)*SIGMA21;
PRINT OXYGEN_var;

QUIT;

*IMPUTATION PHASE:;
*USING PROC MI TO IMPUTE DATA:;
PROC MI DATA=WORK.fitmiss OUT=WORK.fitimpute NIMPUTE=30 SEED=10292012;
MCMC CHAIN=SINGLE DISPLAYINIT INITIAL=EM(ITPRINT) PLOTS=ALL
	 OUTITER=WORK.outiter OUTEST=WORK.outest; 
VAR oxygen runtime runpulse;
RUN;

*DISPLAYING IMPUTED VALUES FOR OBSERVATION 22;
DATA WORK.obs4;
	SET WORK.fitimpute;
	IF ID=4;
	KEEP oxygen;
RUN;

*FOR PLOTTING OUT HISTOGRAM OF IMPUTED:;
%MULTNORM(DATA=WORK.obs4,
		  VAR=oxygen,
		  PLOT= BOTH,
		  HIRES = YES);

*ANALYSIS PHASE:;
PROC MIXED DATA=WORK.fitimpute METHOD=ML COVTEST NOPROFILE ITDETAILS IC ASYCOV;
BY _IMPUTATION_;
MODEL oxygen = runtime runpulse / SOLUTION COVB;
ODS OUTPUT SolutionF=WORK.FixedEffects CovB=WORK.CovMatrices;
RUN;

*POOLING PHASE:;
PROC MIANALYZE PARMS=WORK.fixedeffects CovB(EFFECTVAR=ROWCOL)=Work.CovMatrices EDF=28;
MODELEFFECTS Intercept RunTime RunPulse;
RUN;



*************************************************************************************;
*TRYING DIFFERING NUMBERS OF IMPUTATIONS TO SHOW EFFECT ON STANDARD ERRORS OF PARAMETER ESTIMATES:;

*ONE IMPUTATION;
PROC MI DATA=WORK.fitmiss OUT=WORK.fitimpute1 NIMPUTE=1 SEED=10292012;
MCMC CHAIN=SINGLE DISPLAYINIT INITIAL=EM(ITPRINT) PLOTS=ALL
	 OUTITER=WORK.outiter1 OUTEST=WORK.outest1; 
VAR oxygen runtime runpulse;
RUN;

*ANALYSIS PHASE:;
PROC MIXED DATA=WORK.fitimpute1 METHOD=ML COVTEST NOPROFILE ITDETAILS IC ASYCOV;
MODEL oxygen = runtime runpulse / SOLUTION COVB;
ODS OUTPUT SolutionF=WORK.FixedEffects CovB=WORK.CovMatrices;
RUN;

*TEN IMPUTATIONS;
PROC MI DATA=WORK.fitmiss OUT=WORK.fitimpute10 NIMPUTE=10 SEED=10292012;
MCMC CHAIN=SINGLE DISPLAYINIT INITIAL=EM(ITPRINT) PLOTS=ALL
	 OUTITER=WORK.outiter10 OUTEST=WORK.outest10; 
VAR oxygen runtime runpulse;
RUN;

*ANALYSIS PHASE:;
PROC MIXED DATA=WORK.fitimpute10 METHOD=ML COVTEST NOPROFILE ITDETAILS IC ASYCOV;
BY _IMPUTATION_;
MODEL oxygen = runtime runpulse / SOLUTION COVB;
ODS OUTPUT SolutionF=WORK.FixedEffects10 CovB=WORK.CovMatrices10;
RUN;

*POOLING PHASE:;
PROC MIANALYZE PARMS=WORK.fixedeffects10 CovB(EFFECTVAR=ROWCOL)=Work.CovMatrices10 EDF=28;
MODELEFFECTS Intercept RunTime RunPulse;
RUN;

*THIRTY IMPUTATIONS;
PROC MI DATA=WORK.fitmiss OUT=WORK.fitimpute30 NIMPUTE=30 SEED=10292012;
MCMC CHAIN=SINGLE DISPLAYINIT INITIAL=EM(ITPRINT) PLOTS=ALL
	 OUTITER=WORK.outiter30 OUTEST=WORK.outest30; 
VAR oxygen runtime runpulse;
RUN;

*ANALYSIS PHASE:;
PROC MIXED DATA=WORK.fitimpute30 METHOD=ML COVTEST NOPROFILE ITDETAILS IC ASYCOV;
BY _IMPUTATION_;
MODEL oxygen = runtime runpulse / SOLUTION COVB;
ODS OUTPUT SolutionF=WORK.FixedEffects30 CovB=WORK.CovMatrices30;
RUN;

*POOLING PHASE:;
PROC MIANALYZE PARMS=WORK.fixedeffects30 CovB(EFFECTVAR=ROWCOL)=Work.CovMatrices30 EDF=28;
MODELEFFECTS Intercept RunTime RunPulse;
RUN;


*ONE HUNDRED IMPUTATIONS;
PROC MI DATA=WORK.fitmiss OUT=WORK.fitimpute100 NIMPUTE=100 SEED=10292012;
MCMC CHAIN=SINGLE DISPLAYINIT INITIAL=EM(ITPRINT) PLOTS=ALL
	 OUTITER=WORK.outiter100 OUTEST=WORK.outest100; 
VAR oxygen runtime runpulse;
RUN;

*ANALYSIS PHASE:;
PROC MIXED DATA=WORK.fitimpute100 METHOD=ML COVTEST NOPROFILE ITDETAILS IC ASYCOV;
BY _IMPUTATION_;
MODEL oxygen = runtime runpulse / SOLUTION COVB;
ODS OUTPUT SolutionF=WORK.FixedEffects100 CovB=WORK.CovMatrices100;
RUN;

*POOLING PHASE:;
PROC MIANALYZE PARMS=WORK.fixedeffects100 CovB(EFFECTVAR=ROWCOL)=Work.CovMatrices100 EDF=28;
MODELEFFECTS Intercept RunTime RunPulse;
RUN;
